@@ -382,28 +382,30 @@ class APTRepoCheck(Check):
         # Check up-to-date-ness on Mint mirror
         problems = []
         mint_timestamp = self.get_url_last_modified("http://packages.linuxmint.com/db/version")
-        mint_age = None
-        if mint_timestamp != None:
+        if mint_timestamp is None:
+            problems.append(_("%s is unreachable") % "http://packages.linuxmint.com")
+        else:
             mint_date = datetime.datetime.fromtimestamp(mint_timestamp)
             now = datetime.datetime.now()
             mint_age = (now - mint_date).days
             print_output(f"Mint repository last modified on {mint_date}")
-        for repo in self.mint_repos:
-            if "packages.linuxmint.com" in repo.uri:
-                continue
-            timestamp = self.get_url_last_modified("%s/db/version" % repo.uri)
-            if timestamp == None:
-                # Retry with standard repo layout (for repos which use the mint codenames)
-                new_dist = repo.dist.replace(ORIGIN_CODENAME, DESTINATION_CODENAME)
-                url = "%s/dists/%s/Release" % (repo.uri, new_dist)
-                timestamp = self.get_url_last_modified(url)
-            if timestamp == None:
-                problems.append(_("%s is unreachable") % repo.uri)
-            elif mint_age > 2:
-                date = datetime.datetime.fromtimestamp(timestamp)
-                offset = (mint_date - date).days
-                if mint_age > 2 and offset > 2:
-                    problems.append(_("%s is not up to date. Switch to a different mirror.") % repo.uri)
+
+            for repo in self.mint_repos:
+                if "packages.linuxmint.com" in repo.uri:
+                    continue
+                timestamp = self.get_url_last_modified("%s/db/version" % repo.uri)
+                if timestamp == None:
+                    # Retry with standard repo layout (for repos which use the mint codenames)
+                    new_dist = repo.dist.replace(ORIGIN_CODENAME, DESTINATION_CODENAME)
+                    url = "%s/dists/%s/Release" % (repo.uri, new_dist)
+                    timestamp = self.get_url_last_modified(url)
+                if timestamp == None:
+                    problems.append(_("%s is unreachable") % repo.uri)
+                elif mint_age > 2:
+                    date = datetime.datetime.fromtimestamp(timestamp)
+                    offset = (mint_date - date).days
+                    if mint_age > 2 and offset > 2:
+                        problems.append(_("%s is not up to date. Switch to a different mirror.") % repo.uri)
 
         # Check the base repos can handle destination codename
         for repo in self.base_repos:
@@ -521,6 +523,8 @@ class APTOrphanCheck(Check):
         self.pre_upgrade_orphans = pre_upgrade_orphans
 
     def do_run(self):
+        self.pre_upgrade_orphans.clear()
+
         orphans, foreigns = get_foreign_packages(find_orphans=True, find_downgradable_packages=False)
         if len(orphans) > 0:
             for orphan in orphans:
@@ -533,6 +537,8 @@ class APTOrphanCheck(Check):
                     continue
                 self.pre_upgrade_orphans.append(pkg.name)
 
+        self.info = []
+
         if len(self.pre_upgrade_orphans) > 0:
             self.result = RESULT_INFO
             self.info = []
@@ -548,6 +554,8 @@ class APTOrphanCheck(Check):
             self.info.append(_("Press 'OK' to continue with the upgrade."))
             return
 
+        self.result = RESULT_SUCCESS
+
 # Remove newly orphaned pkgs (post upgrade)
 class APTRemoveOrphansCheck(Check):
 
@@ -992,6 +1000,10 @@ class PostUpgradeCheck(Check):
         print_output("Running apt-get clean")
         run_command("%s clean" % APT_GET)
 
+        # Remove /etc/lsb-release (LMDE only, only /etc/os-release is present in Debian 12+)
+        if IS_LMDE and os.path.exists("/etc/lsb-release"):
+            run_command("rm -f /etc/lsb-release")
+
         # Update initramfs
         print_output("Running update-initramfs -u")
         run_command("update-initramfs -u")
